Interface: LineHoverOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: LineHoverOptions

## # Hierarchy

- `CommonHoverOptions`

  ↳ `LineHoverOptions`

## # Properties

### # hoverBackgroundColor

• hoverBackgroundColor: `Color`

#### # Inherited from

CommonHoverOptions.hoverBackgroundColor

#### # Defined in

index.esm.d.ts:1702
(opens new window)

### # hoverBorderCapStyle

• hoverBorderCapStyle: `CanvasLineCap`

#### # Defined in

index.esm.d.ts:1836
(opens new window)

### # hoverBorderColor

• hoverBorderColor: `Color`

#### # Inherited from

CommonHoverOptions.hoverBorderColor

#### # Defined in

index.esm.d.ts:1701
(opens new window)

### # hoverBorderDash

• hoverBorderDash: `number`[]

#### # Defined in

index.esm.d.ts:1837
(opens new window)

### # hoverBorderDashOffset

• hoverBorderDashOffset: `number`

#### # Defined in

index.esm.d.ts:1838
(opens new window)

### # hoverBorderJoinStyle

• hoverBorderJoinStyle: `CanvasLineJoin`

#### # Defined in

index.esm.d.ts:1839
(opens new window)

### # hoverBorderWidth

• hoverBorderWidth: `number`

#### # Inherited from

CommonHoverOptions.hoverBorderWidth

#### # Defined in

index.esm.d.ts:1700
(opens new window)